@@ -1,9 +1,9 @@
 package Data::Sah::CoerceCommon;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-21'; # DATE
+our $DATE = '2020-05-24'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.048'; # VERSION
+our $VERSION = '0.049'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -13,18 +13,22 @@ our $SUPPORT_OLD_PREFIX = $ENV{PERL_DATA_SAH_COERCE_SUPPORT_OLD_PREFIX} // 1;
 our %Default_Rules = (
     perl => {
         bool       => [qw//],
-        date       => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
         datenotime => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
+        date       => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
         datetime   => [qw/From_float::epoch From_obj::datetime From_obj::time_moment From_str::iso8601/],
         duration   => [qw/From_float::seconds From_obj::datetime_duration From_str::human From_str::iso8601/],
+        float      => [qw/From_str::percent/],
+        num        => [qw/From_str::percent/],
         timeofday  => [qw/From_obj::date_timeofday From_str::hms/],
     },
     js => {
         bool       => [qw/From_float::zero_one From_str::common_words/],
+        datenotime => [qw/From_float::epoch From_obj::date From_str::date_parse/],
         date       => [qw/From_float::epoch From_obj::date From_str::date_parse/],
         datetime   => [qw/From_float::epoch From_obj::date From_str::date_parse/],
-        datenotime => [qw/From_float::epoch From_obj::date From_str::date_parse/],
         duration   => [qw/From_float::seconds From_str::iso8601/],
+        #float      => [qw/From_str::percent/],
+        #num        => [qw/From_str::percent/],
         timeofday  => [qw/From_str::hms/],
     },
 );
@@ -243,7 +247,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.048 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2020-05-21.
+This document describes version 0.049 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2020-05-24.
 
 =head1 FUNCTIONS
 
